from setuptools import setup

setup(
    name='libiio-c',
    version="1.0.0",
    description='libiio-c - listed by Cycode to prevent confusion',
    long_description="libiio-c",
    long_description_content_type='text/markdown',
)
